@@ -51,7 +51,7 @@ static const QMap<QString, QRegularExpression> s_shortcutWhitelist{
         QStringLiteral("mute|decrease_volume|increase_volume")
     )},
     {QStringLiteral("/component/org_kde_powerdevil"), QRegularExpression(
-        QStringLiteral("Increase Screen Brightness|Decrease Screen Brightness|Increase Keyboard Brightness|Decrease Keyboard Brightness|Turn Off Screen")
+        QStringLiteral("Increase Screen Brightness|Decrease Screen Brightness|Increase Keyboard Brightness|Decrease Keyboard Brightness|Turn Off Screen|Sleep|Hibernate")
     )},
     {QStringLiteral("/component/KDE_Keyboard_Layout_Switcher"), QRegularExpression(
         QStringLiteral("Switch to Next Keyboard Layout|Switch keyboard layout to .*")
